@@ -33,6 +33,8 @@ class CrudMethods(Enum):
     DELETE_ONE = "DELETE_ONE"
     DELETE_MANY = "DELETE_MANY"
     POST_REDIRECT_GET = "POST_REDIRECT_GET"
+    FIND_ONE_WITH_FOREIGN_TREE = "FIND_ONE_WITH_FOREIGN_TREE"
+    FIND_MANY_WITH_FOREIGN_TREE = "FIND_MANY_WITH_FOREIGN_TREE"
 
     @staticmethod
     def get_table_full_crud_method():
@@ -44,7 +46,8 @@ class CrudMethods(Enum):
         return [CrudMethods.FIND_MANY, CrudMethods.FIND_ONE,
                 CrudMethods.UPDATE_MANY, CrudMethods.UPDATE_ONE,
                 CrudMethods.PATCH_MANY, CrudMethods.PATCH_ONE, CrudMethods.CREATE_MANY,
-                CrudMethods.DELETE_MANY, CrudMethods.DELETE_ONE]
+                 CrudMethods.DELETE_MANY, CrudMethods.DELETE_ONE, CrudMethods.FIND_ONE_WITH_FOREIGN_TREE,
+                 CrudMethods.FIND_MANY_WITH_FOREIGN_TREE]
 
 
 class RequestMethods(Enum):
@@ -57,7 +60,10 @@ class RequestMethods(Enum):
 
 class CRUDRequestMapping(Enum):
     FIND_ONE = RequestMethods.GET
+    FIND_ONE_WITH_FOREIGN_TREE = RequestMethods.GET
+
     FIND_MANY = RequestMethods.GET
+    FIND_MANY_WITH_FOREIGN_TREE = RequestMethods.GET
 
     UPDATE_ONE = RequestMethods.PUT
     UPDATE_MANY = RequestMethods.PUT
@@ -120,6 +126,7 @@ class MatchingPatternInStringBase(StrEnum):
     case_sensitive = auto()
     not_case_insensitive = auto()
     not_case_sensitive = auto()
+    contains = auto()
 
 
 class PGSQLMatchingPattern(StrEnum):
@@ -151,3 +158,5 @@ class JSONBMatchingMode(str, Enum):
 class SessionObject(StrEnum):
     sqlalchemy = auto()
     databases = auto()
+
+FOREIGN_PATH_PARAM_KEYWORD = "__pk__"
\ No newline at end of file
